==> certmanager-model-v1alpha2-6.4.1-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VenafiTPPFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceFluent;

 /**
  * Generated
  */
public interface VenafiTPPFluent<A extends VenafiTPPFluent<A>> extends Fluent<A>{
  public String getCaBundle();
  public A withCaBundle(String caBundle);
  public Boolean hasCaBundle();
  
  /**
   * This method has been deprecated, please use method buildCredentialsRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getCredentialsRef();
  public LocalObjectReference buildCredentialsRef();
  public A withCredentialsRef(LocalObjectReference credentialsRef);
  public Boolean hasCredentialsRef();
  public A withNewCredentialsRef(String name);
  public VenafiTPPFluent.CredentialsRefNested<A> withNewCredentialsRef();
  public VenafiTPPFluent.CredentialsRefNested<A> withNewCredentialsRefLike(LocalObjectReference item);
  public VenafiTPPFluent.CredentialsRefNested<A> editCredentialsRef();
  public VenafiTPPFluent.CredentialsRefNested<A> editOrNewCredentialsRef();
  public VenafiTPPFluent.CredentialsRefNested<A> editOrNewCredentialsRefLike(LocalObjectReference item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public interface CredentialsRefNested<N> extends Nested<N>,LocalObjectReferenceFluent<VenafiTPPFluent.CredentialsRefNested<N>>{
    public N and();
    public N endCredentialsRef();
    
  }
  
}

==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/VenafiTPPFluent.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.Deprecated;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReference;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.certmanager.api.model.meta.v1.LocalObjectReferenceFluent;

 /**
  * Generated
  */
public interface VenafiTPPFluent<A extends VenafiTPPFluent<A>> extends Fluent<A>{
  public String getCaBundle();
  public A withCaBundle(String caBundle);
  public Boolean hasCaBundle();
  
  /**
   * This method has been deprecated, please use method buildCredentialsRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public LocalObjectReference getCredentialsRef();
  public LocalObjectReference buildCredentialsRef();
  public A withCredentialsRef(LocalObjectReference credentialsRef);
  public Boolean hasCredentialsRef();
  public A withNewCredentialsRef(String name);
  public VenafiTPPFluent.CredentialsRefNested<A> withNewCredentialsRef();
  public VenafiTPPFluent.CredentialsRefNested<A> withNewCredentialsRefLike(LocalObjectReference item);
  public VenafiTPPFluent.CredentialsRefNested<A> editCredentialsRef();
  public VenafiTPPFluent.CredentialsRefNested<A> editOrNewCredentialsRef();
  public VenafiTPPFluent.CredentialsRefNested<A> editOrNewCredentialsRefLike(LocalObjectReference item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public interface CredentialsRefNested<N> extends Nested<N>,LocalObjectReferenceFluent<VenafiTPPFluent.CredentialsRefNested<N>>{
    public N and();
    public N endCredentialsRef();
    
  }
  
}
